import os
import glob
import argparse
from Bio import SeqIO


prefix_seq_by_file_name_usage = '''
========= prefix_seq_by_file_name example commands =========

BioSAK prefix_seq_by_file_name -i gnm_dir -x fa -o op_dir

============================================================
'''

def sep_path_basename_ext(file_in):

    f_path, file_name = os.path.split(file_in)
    if f_path == '':
        f_path = '.'
    f_base, f_ext = os.path.splitext(file_name)
    return f_path, f_base, f_ext


def prefix_seq_by_file_name(args):

    seq_file_in     = args['i']
    file_extension  = args['x']
    op_dir          = args['o']
    keep_desc       = args['desc']

    seq_in_re = '%s/*.%s' % (seq_file_in, file_extension)
    seq_in_list = glob.glob(seq_in_re)

    if len(seq_in_list) == 0:
        print('No sequence file detected, program exited!')
        exit()

    if os.path.isdir(op_dir) is True:
        print('Output folder detected, program exited: %s' % op_dir)
        exit()
    else:
        os.mkdir(op_dir)

    file_index = 1
    for each_file in seq_in_list:
        f_path, f_base, f_ext = sep_path_basename_ext(each_file)

        print('Processing %s/%s: %s' % (file_index, len(seq_in_list), f_base))
        file_out = '%s/%s%s' % (op_dir, f_base, f_ext)
        file_out_handle = open(file_out, 'w')
        seq_index = 1
        for each_seq in SeqIO.parse(each_file, 'fasta'):
            if keep_desc is True:
                file_out_handle.write('>%s_%s %s\n' % (f_base, seq_index, each_seq.description))
            else:
                file_out_handle.write('>%s_%s\n' % (f_base, seq_index))
            file_out_handle.write('%s\n' % each_seq.seq)
            seq_index += 1
        file_out_handle.close()
        file_index += 1

    print('Done!')


if __name__ == '__main__':

    prefix_seq_by_file_name_parser = argparse.ArgumentParser(usage=prefix_seq_by_file_name_usage)
    prefix_seq_by_file_name_parser.add_argument('-i',         required=True,                         help='input sequence folder')
    prefix_seq_by_file_name_parser.add_argument('-x',         required=False, default='fasta',       help='file extension, default: fasta')
    prefix_seq_by_file_name_parser.add_argument('-o',         required=True,                         help='output folder')
    prefix_seq_by_file_name_parser.add_argument('-desc',      action="store_true",                   help='keep sequence description')
    args = vars(prefix_seq_by_file_name_parser.parse_args())
    prefix_seq_by_file_name(args)




def xml_to_txt(xml_file, txt_file):

    txt_file_handle = open(txt_file, 'w')
    for each_line in open(xml_file):
        each_line = each_line.strip()
        if (each_line.count('<') == 1) and (each_line.count('>') == 1):
            pass
        else:
            each_line = each_line.split('</')[0]
            title_str = each_line.split('>')[0][1:]
            value_str = each_line.split('>')[-1]
            if 'display_name' in title_str:
                title_str = title_str.split('display_name')[1].replace('=','').replace('"','')
            elif title_str.count('=') == 1:
                title_str = title_str.split('=')[1].replace('"','')
            elif title_str.count('=') == 0:
                title_str = title_str
            elif 'is_primary' in title_str:
                title_str = title_str.split('is_primary')[0].split('=')[1].replace('"','')
            txt_file_handle.write('%s\t%s\n' % (title_str, value_str))
    txt_file_handle.close()


xml_file = '/Users/songweizhi/Desktop/demo/biosample_wd/SAMEA13322663.xml'
txt_file = '/Users/songweizhi/Desktop/demo/biosample_wd/SAMEA13322663.txt'


import pandas as pd

df = pd.read_xml(xml_file)
print(df)
# df.to_csv(txt_file, index=False)